.. currentmodule:: sardana.pool.poolexternal

:mod:`~sardana.pool.poolexternal`
======================================

.. automodule:: sardana.pool.poolexternal

.. rubric:: Functions

.. hlist::
    :columns: 3

    * :func:`PoolExternalObject`

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolBaseExternalObject`
    * :class:`PoolTangoObject`

.. autofunction:: PoolExternalObject

PoolBaseExternalObject
-----------------------

.. inheritance-diagram:: PoolBaseExternalObject
    :parts: 1
    
.. autoclass:: PoolBaseExternalObject
    :show-inheritance:
    :members:
    :undoc-members:

PoolTangoObject
--------------------------

.. inheritance-diagram:: PoolTangoObject
    :parts: 1
    
.. autoclass:: PoolTangoObject
    :show-inheritance:
    :members:
    :undoc-members:
